import { getAllRoleList } from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import { h } from 'vue';
import { Switch } from 'ant-design-vue';
import { useMessage } from '@/hooks/web/useMessage';
import { changeFlagApi } from '@/api/system/user/user';
// 引入开关组件
type CheckedType = boolean | string | number;

/** 列表筛选项*/
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '',
    component: 'Input',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '输入关键字搜索',
    },
  },
];
export const detailSchemas: FormSchema[] = [
  {
    field: 'name',
    label: '',
    component: 'Input',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '输入关键字搜索',
    },
  },
];

export const detailsColumns: BasicColumn[] = [
  {
    title: 'API名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '调用次数',
    dataIndex: 'callNum',
    width: 120,
  },
  {
    title: '调用成功次数',
    dataIndex: 'callSuccessNum',
    width: 120,
  },
  {
    title: '调用失败次数',
    dataIndex: 'callFailNum',
    width: 120,
  },
  {
    title: '调用状态',
    dataIndex: 'flag',
    width: 120,
  },
  {
    title: '调用开始时间',
    dataIndex: 'startTime',
    width: 120,
  },
  {
    title: '调用结束时间',
    dataIndex: 'endTime',
    width: 120,
  },
];
/** 列表展示字段*/
export const columns: BasicColumn[] = [
  {
    title: '域名地址',
    dataIndex: 'domainName',
    width: 120,
  },
  {
    title: '描述',
    dataIndex: 'description',
    width: 120,
  },
  {
    title: '创建者',
    dataIndex: 'createdBy',
    width: 120,
  },
  {
    title: '创建时间',
    dataIndex: 'creationTime',
    width: 120,
  },
  {
    title: '关联API路由',
    dataIndex: 'apiRouter',
    width: 120,
    slots: { customRender: 'apiRouter' },
  },
];

/** 弹窗-关联api路由列表展示字段*/
export const columns2: BasicColumn[] = [
  {
    title: '路由名称',
    dataIndex: 'routerName',
    width: 120,
  },
  {
    title: '业务分组',
    dataIndex: 'grouping',
    width: 120,
  },
  {
    title: '请求方式',
    dataIndex: 'requestManner',
    width: 120,
  },
  {
    title: '协议类型',
    dataIndex: 'protocolType',
    width: 120,
  },
  {
    title: '动态路由',
    dataIndex: 'dynamicRouter',
    width: 120,
  },
];
export const columns0: BasicColumn[] = [
  {
    // title: 'api列名',
    dataIndex: 'apiColumnName',
    width: 120,
  },
];

/** 关联api路由表单*/
export const apiRouterFormSchema: any[] = [
  {
    field: 'account',
    label: '账号',
    component: 'Input',
    defaultValue: 'admin',
    componentProps: {
      readOnly: true,
      disabled: true,
    },
  },
  {
    field: 'name',
    label: '用户名称',
    component: 'Input',
    defaultValue: 'admin',
    componentProps: {
      readOnly: true,
      disabled: true,
    },
  },
  {
    field: 'token',
    label: '用户token',
    component: 'InputTextArea',
    defaultValue: '13248123468126348asdfyi9adfa8ya8d67f8adyf8as67df86as87df',
    componentProps: {
      rows: 4,
      readOnly: true,
      disabled: true,
    },
  },
  {
    field: 'tokenTime',
    label: 'token自动刷新频率',
    slot: 'tokenTime',
    component: 'InputNumber',
    defaultValue: 1,
    labelWidth: 160,
    componentProps: {
      min: 1,
      max: 9999,
      // disabled: true,
    },
  },
  {
    //用户密钥
    field: 'userKey',
    label: '用户密钥',
    slot: 'userKey',
    component: 'Input',
    defaultValue: 'transwarp12345',
    componentProps: {
      readOnly: true,
      disabled: true,
      style: { width: '27%' },
    },
  },
];
/**新建文件夹 表单*/
export const createDocumentFormSchema: FormSchema[] = [
  {
    field: 'domainName',
    label: '域名地址',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入域名地址',
      },
    ],
    componentProps: {
      placeholder: '请输入域名地址',
    },
  },
  {
    field: 'description',
    label: '描述',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
];
// const [registerTable] = useTable({
//   title: '可编辑单元格示例',
//   api: demoListApi,
//   columns: columns,
//   showIndexColumn: false,
//   bordered: true,
// });
